@@ -1,46 +1,26 @@
-#
-# Configuration and state data relating to the human using Padre.
-#
-
 package Padre::Config::Human;
 
+# Configuration and state data relating to the human using Padre.
+
 use 5.008;
 use strict;
 use warnings;
+use Storable        ();
+use YAML::Tiny      ();
+use Params::Util    ();
+use Padre::Constant ();
 
-use Carp qw{ croak              };
-use Params::Util qw{ _HASH0             };
-use Storable qw{ dclone             };
-use YAML::Tiny qw{ DumpFile LoadFile  };
+our $VERSION = '0.36';
 
-use Padre::Config::Constants qw{ $CONFIG_FILE_USER };
-
-our $VERSION = '0.35';
-
-my $REVISION = 1;    # config schema revision
-
-# -- constructors
-
-#
-# my $config = Padre::Config::Human->_new( $href );
-#
-# create & return a new config object. if $href is not supplied, the config
-# object will be empty. this constructor is private and should not be used
-# outside this class.
-#
-sub _new {
-	my ( $class, $self ) = @_;
-	$self ||= {};
-	bless $self, $class;
-	return $self;
-}
+# Config schema revision
+my $REVISION = 1;
 
 #
 # my $config = Padre::Config::Human->create;
 #
 sub create {
 	my $class = shift;
-	my $self = $class->_new( { version => $REVISION } );
+	my $self = bless { version => $REVISION }, $class;
 	$self->write;
 	return $self;
 }
@@ -52,11 +32,13 @@ sub read {
 	my $class = shift;
 
 	# Load the user configuration
-	my $hash = eval { LoadFile($CONFIG_FILE_USER) };
-	return unless _HASH0($hash);
+	my $hash = eval { YAML::Tiny::LoadFile( Padre::Constant::CONFIG_HUMAN ) };
+	unless ( Params::Util::_HASH0($hash) ) {
+		return;
+	}
 
 	# Create and return the object
-	return $class->_new($hash);
+	return bless $hash, $class;
 }
 
 # -- public methods
@@ -65,8 +47,7 @@ sub read {
 # my $revision = $config->version;
 #
 sub version {
-	my $self = shift;
-	$self->{version};    # stored as other preferences!
+	$_[0]->{version};
 }
 
 #
@@ -75,11 +56,11 @@ sub version {
 sub write {
 	my $self = shift;
 
-	# Clone and remove the bless
-	my $copy = dclone( +{%$self} );
-
-	# Save the user configuration
-	DumpFile( $CONFIG_FILE_USER, $copy );
+	# Save the unblessed clone of the user configuration hash
+	YAML::Tiny::DumpFile(
+		Padre::Constant::CONFIG_HUMAN,
+		Storable::dclone( +{%$self} ),
+	);
 
 	return 1;
 }
@@ -88,11 +69,12 @@ sub write {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Padre::Config::Human - Padre configuration storing personal preferences
 
-
 =head1 DESCRIPTION
 
 This class implements the personal preferences of Padre's users. See C<Padre::Config>
@@ -102,7 +84,6 @@ All human settings are stored in a hash as top-level keys (no hierarchy). The ha
 then dumped in C<config.yml>, a YAML file in Padre's preferences directory (see
 C<Padre::Config>). 
 
-
 =head1 PUBLIC API
 
 =head2 Constructors
@@ -116,7 +97,6 @@ still store the config schema revision - see version() below).
 
 No params.
 
-
 =item my $config = Padre::Config::Human->read;
 
 Load & return the user configuration from the yaml file. Return undef in
@@ -124,10 +104,8 @@ case of failure.
 
 No params.
 
-
 =back
 
-
 =head2 Object methods
 
 =over 4
@@ -140,7 +118,6 @@ version is stored with the other user preferences at the same level.
 
 No params.
 
-
 =item $config->write;
 
 (Over-)write user configuration to the yaml file.
@@ -149,7 +126,6 @@ No params.
 
 =back
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2009 The Padre development team as listed in Padre.pm.
