@@ -48,7 +48,7 @@ use Padre::Wx     ();
 use constant DEFAULT  => 'en-gb';
 use constant SHAREDIR => File::Spec->rel2abs( Padre::Util::sharedir('locale') );
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 # The RFC4646 table is the primary language data table and contains
 # mappings from a Padre-supported language to all the relevant data
@@ -149,6 +149,16 @@ BEGIN {
 			supported => 1,
 		},
 
+		'cz' => {
+			gettext   => _T('Czech'),
+			utf8text  => 'Česky',
+			iso639    => 'cz',
+			iso3166   => undef,
+			wxid      => Wx::wxLANGUAGE_CZECH,
+			fallback  => [],
+			supported => 1,
+		},
+
 		'de' => {
 			gettext   => _T('German'),
 			utf8text  => 'Deutsch',
@@ -198,12 +208,13 @@ BEGIN {
 		},
 
 		'es-ar' => {
-			gettext  => _T('Spanish (Argentina)'),
-			utf8text => 'Español (Argentina)',
-			iso639   => 'sp',
-			iso3166  => 'AR',
-			wxid     => Wx::wxLANGUAGE_SPANISH_ARGENTINA,
-			fallback => [ 'es-es', 'en-us' ],
+			gettext   => _T('Spanish (Argentina)'),
+			utf8text  => 'Español (Argentina)',
+			iso639    => 'sp',
+			iso3166   => 'AR',
+			wxid      => Wx::wxLANGUAGE_SPANISH_ARGENTINA,
+			fallback  => [ 'es-es', 'en-us' ],
+			supported => 0,
 		},
 
 		'es-es' => {
@@ -220,13 +231,24 @@ BEGIN {
 			supported => 1,
 		},
 
+		'fa' => {
+			gettext   => _T('Persian (Iran)'),
+			utf8text  => 'پارسی (ایران)',
+			iso639    => 'prs',
+			iso3166   => undef,
+			wxid      => Wx::wxLANGUAGE_FARSI,
+			fallback  => [],
+			supported => 1
+		},
+
 		'fr-ca' => {
-			gettext  => _T('French (France)'),
-			utf8text => 'Français (Canada)',
-			iso639   => 'fr',
-			iso3166  => 'CA',
-			wxid     => Wx::wxLANGUAGE_FRENCH_CANADIAN,
-			fallback => ['fr-fr'],
+			gettext   => _T('French (France)'),
+			utf8text  => 'Français (Canada)',
+			iso639    => 'fr',
+			iso3166   => 'CA',
+			wxid      => Wx::wxLANGUAGE_FRENCH_CANADIAN,
+			fallback  => ['fr-fr'],
+			supported => 0,
 		},
 
 		'fr-fr' => {
@@ -312,12 +334,23 @@ BEGIN {
 		},
 
 		'nl-be' => {
-			gettext  => _T('Dutch (Belgium)'),
-			utf8text => 'Nederlands (België)',
-			iso639   => 'en',
-			iso3166  => 'BE',
-			wxid     => Wx::wxLANGUAGE_DUTCH_BELGIAN,
-			fallback => ['nl-nl'],
+			gettext   => _T('Dutch (Belgium)'),
+			utf8text  => 'Nederlands (België)',
+			iso639    => 'en',
+			iso3166   => 'BE',
+			wxid      => Wx::wxLANGUAGE_DUTCH_BELGIAN,
+			fallback  => ['nl-nl'],
+			supported => 1,
+		},
+
+		'no' => {
+			gettext   => _T('Norwegian (Norway)'),
+			utf8text  => 'Norsk (Norge)',
+			iso639    => 'no',
+			iso3166   => 'NO',
+			wxid      => Wx::wxLANGUAGE_NORWEGIAN_BOKMAL,
+			fallback  => [ 'en-gb', 'en-us' ],
+			supported => 1,
 		},
 
 		'pl' => {
@@ -341,12 +374,13 @@ BEGIN {
 		},
 
 		'pt-pt' => {
-			gettext  => _T('Portuguese (Portugal)'),
-			utf8text => 'Português (Europeu)',
-			iso639   => 'pt',
-			iso3166  => 'PT',
-			wxid     => Wx::wxLANGUAGE_PORTUGUESE,
-			fallback => ['pt-br'],
+			gettext   => _T('Portuguese (Portugal)'),
+			utf8text  => 'Português (Europeu)',
+			iso639    => 'pt',
+			iso3166   => 'PT',
+			wxid      => Wx::wxLANGUAGE_PORTUGUESE,
+			fallback  => ['pt-br'],
+			supported => 0,
 		},
 
 		'ru' => {
@@ -365,7 +399,7 @@ BEGIN {
 			iso639    => 'zh',
 			iso3166   => undef,
 			wxid      => Wx::wxLANGUAGE_CHINESE,
-			fallback  => [ 'zh-cn', 'zh-tw', 'en-us' ],
+			fallback  => [ 'zh-tw', 'zh-cn', 'en-us' ],
 			supported => 0,
 		},
 
@@ -375,17 +409,18 @@ BEGIN {
 			iso639    => 'zh',
 			iso3166   => 'CN',
 			wxid      => Wx::wxLANGUAGE_CHINESE_SIMPLIFIED,
-			fallback  => [],
+			fallback  => [ 'zh-tw', 'en-us' ],
 			supported => 1,
 		},
 
 		'zh-tw' => {
-			gettext  => _T('Chinese (Traditional)'),
-			utf8text => '正體中文 (繁體)',
-			iso639   => 'zh',
-			iso3166  => 'TW',
-			wxid     => Wx::wxLANGUAGE_CHINESE_TRADITIONAL,
-			fallback => [ 'zh-cn', 'en-us' ],
+			gettext   => _T('Chinese (Traditional)'),
+			utf8text  => '正體中文 (繁體)',
+			iso639    => 'zh',
+			iso3166   => 'TW',
+			wxid      => Wx::wxLANGUAGE_CHINESE_TRADITIONAL,
+			fallback  => [ 'zh-cn', 'en-us' ],
+			supported => 1,
 		},
 
 		# RFC4646 supports the interesting idea of comedy languages.
@@ -393,12 +428,13 @@ BEGIN {
 		# Mostly what these do is uncover issues that might arise when
 		# a language is not supported by various older standards.
 		'x-klingon' => {
-			gettext  => _T('Klingon'),
-			utf8text => 'Klingon',       # TODO Fix this at some point
-			iso639   => undef,
-			iso3166  => undef,
-			wxid     => undef,
-			fallback => ['en-gb'],       # Debatable... :)
+			gettext   => _T('Klingon'),
+			utf8text  => 'Klingon',       # TODO Fix this at some point
+			iso639    => undef,
+			iso3166   => undef,
+			wxid      => undef,
+			fallback  => ['en-gb'],       # Debatable... :)
+			supported => 0,
 		},
 	);
 
@@ -444,6 +480,12 @@ sub rfc4646 {
 	return $RFC4646{$locale}->{actual};
 }
 
+#
+sub iso639 {
+	my $id     = rfc4646();
+	my $iso693 = $RFC4646{$id}{iso639};
+}
+
 # Given a rfc4646 identifier, sets the language globally
 # and returns the relevant Wx::Locale object.
 sub object {
