@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use PPI;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 #####################################################################
 # Assorted Search Functions
@@ -22,7 +22,7 @@ sub find_unmatched_brace {
 # lexical (my)
 # our (our, doh)
 # dynamic (local)
-# TODO: add "use vars..." as "package" scope
+# package (use vars)
 # Returns a hash reference containing the three category names
 # each pointing at a hash which contains '$variablename' => locations.
 # locations is an array reference containing one or more PPI-style
@@ -41,7 +41,9 @@ sub get_all_variable_declarations {
 
 	my $declarations = $document->find(
 		sub {
-			return 0 unless $_[1]->isa('PPI::Statement::Variable');
+			return 0
+				unless $_[1]->isa('PPI::Statement::Variable')
+					or $_[1]->isa('PPI::Statement::Include');
 			return 1;
 		},
 	);
@@ -49,28 +51,49 @@ sub get_all_variable_declarations {
 	my %our;
 	my %lexical;
 	my %dynamic;
+	my %package;
 	foreach my $decl (@$declarations) {
-		my $type     = $decl->type();
-		my @vars     = $decl->variables;
-		my $location = $decl->location;
+		if ( $decl->isa('PPI::Statement::Variable') ) {
+			my $type     = $decl->type();
+			my @vars     = $decl->variables;
+			my $location = $decl->location;
 
-		my $target_type;
+			my $target_type;
 
-		if ( $type eq 'my' ) {
-			$target_type = \%lexical;
-		} elsif ( $type eq 'our' ) {
-			$target_type = \%our;
-		} elsif ( $type eq 'local' ) {
-			$target_type = \%dynamic;
+			if ( $type eq 'my' ) {
+				$target_type = \%lexical;
+			} elsif ( $type eq 'our' ) {
+				$target_type = \%our;
+			} elsif ( $type eq 'local' ) {
+				$target_type = \%dynamic;
+			}
+
+			foreach my $var (@vars) {
+				$target_type->{$var} ||= [];
+				push @{ $target_type->{$var} }, $location;
+			}
 		}
 
-		foreach my $var (@vars) {
-			$target_type->{$var} ||= [];
-			push @{ $target_type->{$var} }, $location;
-		}
-	}
+		# find use vars...
+		elsif ( $decl->isa('PPI::Statement::Include')
+			and $decl->module eq 'vars'
+			and $decl->type   eq 'use' )
+		{
 
-	return ( { our => \%our, lexical => \%lexical, dynamic => \%dynamic } );
+			# do it the low-tech way
+			my $string   = $decl->content();
+			my $location = $decl->location;
+
+			my @vars = $string =~ /([\%\@\$][\w_:]+)/g;
+			foreach my $var (@vars) {
+				$package{$var} ||= [];
+				push @{ $package{$var} }, $location;
+			}
+
+		}
+	}    # end foreach declaration
+
+	return ( { our => \%our, lexical => \%lexical, dynamic => \%dynamic, package => \%package } );
 }
 
 #####################################################################
@@ -165,6 +188,21 @@ sub find_variable_declaration {
 					last;
 				}
 
+				# find use vars ...
+				elsif ( $elem->isa("PPI::Statement::Include")
+					and $elem->module eq 'vars'
+					and $elem->type   eq 'use' )
+				{
+
+					# do it the low-tech way
+					my $string = $elem->content();
+					my @vars = $string =~ /([\%\@\$][\w_:]+)/g;
+					if ( grep { $varname eq $_ } @vars ) {
+						$declaration = $elem;
+						last;
+					}
+				}
+
 			}
 			last if $declaration or $cursor == $document;
 		}
