@@ -37,9 +37,9 @@ There are some things we can be B<very> clear about.
 you first explicitly telling us we are allowed to collect that type
 of information.
 
-2. We will B<NEVER> do any information that would result in
-a copyright violation. That means we won't collect, record, or
-transmit the contents of any file.
+2. We will B<NEVER> copy any information that would result in
+a violation of your legal rights, including copyright.
+That means we won't collect, record, or transmit the contents of any file.
 
 3. We will B<NEVER> transmit the name of any file, or the cryptographic
 hash of any file, or any other unique identifier of any file, although we
@@ -69,11 +69,11 @@ use strict;
 use warnings;
 use Padre::Plugin ();
 
-our $VERSION = '0.35';
-use base 'Padre::Plugin';
+our $VERSION = '0.36';
+our @ISA     = 'Padre::Plugin';
 
-#####################################################################
-# Constructor
+######################################################################
+# Padre::Plugin Methods
 
 sub plugin_name {
 	'Padre Popularity Contest';
@@ -81,10 +81,16 @@ sub plugin_name {
 
 sub plugin_enable {
 	my $self = shift;
+	$self->SUPER::plugin_enable;
 
 	# Load the config
 	$self->{config} = $self->config_read;
 
+	# Trigger the ping at enable time.
+	# Not sure how load'y this will be, but lets try it
+	# for now and see how things end up.
+	$self->_ping;
+
 	return 1;
 }
 
@@ -96,19 +102,24 @@ sub plugin_disable {
 		$self->config_write( delete $self->{config} );
 	}
 
-	return 1;
+	# Make sure our task class is unloaded
+	require Class::Unload;
+	Class::Unload->unload('Padre::Plugin::PopularityContext::Ping');
+
+	$self->SUPER::plugin_disable;
 }
 
 sub menu_plugins_simple {
-	my $self = shift;
-	return $self->plugin_name => [
-		Wx::gettext("About") => 'show_about',
-
-		#		Wx::gettext("Submit")      => 'submit',
+	return shift->plugin_name => [
+		Wx::gettext("About") => '_about',
+		Wx::gettext("Ping")  => '_ping',
 	];
 }
 
-sub show_about {
+######################################################################
+# Private Methods
+
+sub _about {
 	my $self  = shift;
 	my $about = Wx::AboutDialogInfo->new;
 	$about->SetName(__PACKAGE__);
@@ -117,13 +128,13 @@ sub show_about {
 	return;
 }
 
-sub submit {
+sub _ping {
 	my $self = shift;
-	require Padre::Task::HTTPClient;
-	my $task = Padre::Task::HTTPClient->new;
-	$task->schedule;
-	my $main = Padre->ide->wx->main;
-	$main->message("Data will be submitted in the background. Thank you.");
+
+	# Send the request
+	require Padre::Plugin::PopularityContest::Ping;
+	Padre::Plugin::PopularityContest::Ping->new->schedule;
+
 	return;
 }
 
