@@ -4,11 +4,11 @@ use 5.008;
 use strict;
 use warnings;
 use Carp 'croak';
-use Params::Util qw{_IDENTIFIER _CLASS _INSTANCE};
+use Params::Util qw{_STRING _IDENTIFIER _CLASS _INSTANCE};
 use Padre::Current ();
 use Padre::Locale  ();
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use overload
 	'bool' => sub {1},
@@ -120,9 +120,8 @@ sub can_editor {
 # Interface Methods
 
 sub plugin_icon {
-	my $self  = shift;
-	my $class = $self->class;
-	return $class->plugin_icon if $class->can('plugin_icon');
+	my $class = shift->class;
+	$class->can('plugin_icon') and $class->plugin_icon;
 }
 
 sub plugin_name {
@@ -179,7 +178,7 @@ sub enable {
 	# If the plugin defines document types, register them
 	my @documents = $self->object->registered_documents;
 	if (@documents) {
-		Class::Autouse->load('Padre::Document');
+		require Padre::Document;
 	}
 	while (@documents) {
 		my $type  = shift @documents;
@@ -187,6 +186,12 @@ sub enable {
 		$Padre::Document::MIME_CLASS{$type} = $class;
 	}
 
+	# If the plugin has a hook for the context menu, cache it
+	if ( $self->object->can('event_on_context_menu') ) {
+		my $cxt_menu_hook_cache = Padre->ide->plugin_manager->plugins_with_context_menu;
+		$cxt_menu_hook_cache->{$name} = 1;
+	}
+
 	# Update the status
 	$self->status('enabled');
 	$self->errstr('');
@@ -224,6 +229,10 @@ sub disable {
 		return 1;
 	}
 
+	# If the plugin has a hook for the context menu, cache it
+	my $cxt_menu_hook_cache = Padre->ide->plugin_manager->plugins_with_context_menu;
+	delete $cxt_menu_hook_cache->{ $self->name() };
+
 	# Update the status
 	$self->status('disabled');
 	$self->errstr('');
@@ -235,15 +244,15 @@ sub disable {
 # Support Methods
 
 sub _STATUS {
-	(   defined $_[0] and !ref $_[0] and +{
-			error        => 1,
-			unloaded     => 1,
-			loaded       => 1,
-			incompatible => 1,
-			disabled     => 1,
-			enabled      => 1,
-			}->{ $_[0] }
-	) ? $_[0] : undef;
+	_STRING( $_[0] ) or return undef;
+	return {
+		error        => 1,
+		unloaded     => 1,
+		loaded       => 1,
+		incompatible => 1,
+		disabled     => 1,
+		enabled      => 1,
+	}->{ $_[0] };
 }
 
 1;
