@@ -33,8 +33,8 @@ use strict;
 use warnings;
 use Pod::Simple::XHTML ();
 
-our $VERSION = '0.35';
-use base 'Pod::Simple::XHTML';
+our $VERSION = '0.36';
+our @ISA     = 'Pod::Simple::XHTML';
 
 use Class::XSAccessor getters => {
 	html => 'scratch',    # Method to fetch out the scratch
