@@ -5,8 +5,8 @@ use strict;
 use warnings;
 use Padre::Project ();
 
-our $VERSION = '0.35';
-use base 'Padre::Project';
+our $VERSION = '0.36';
+our @ISA     = 'Padre::Project';
 
 use overload 'bool' => sub () {0};
 
