@@ -6,8 +6,8 @@ use strict;
 use warnings;
 use Padre::Project ();
 
-our $VERSION = '0.35';
-use base 'Padre::Project';
+our $VERSION = '0.36';
+our @ISA     = 'Padre::Project';
 
 sub inspector {
 	my $self = shift;
