@@ -2,10 +2,10 @@ package Padre::Task::Debug::Crashing;
 
 use strict;
 use warnings;
+use Padre::Task ();
 
-use base 'Padre::Task';
-
-our $VERSION = '0.35';
+our $VERSION = '0.36';
+our @ISA     = 'Padre::Task';
 
 sub run {
 	my ($self) = @_;
