@@ -3,12 +3,12 @@ package Padre::Task::HTTPClient;
 use strict;
 use warnings;
 use Params::Util qw{_CODE _INSTANCE};
-use Padre::Task    ();
-use Padre::Current ();
-use Padre::Wx      ();
+use URI              ();
+use HTTP::Request    ();
+use Padre::Task::LWP ();
 
-our $VERSION = '0.35';
-use base 'Padre::Task';
+our $VERSION = '0.36';
+our @ISA     = 'Padre::Task::LWP';
 
 =pod
 
@@ -26,32 +26,30 @@ Sending and receiving data via HTTP.
 
 # TODO this should probably run later,
 # not when the plugin is enabled
-sub run {
-	my $self = shift;
+sub new {
+	my $class = shift;
 
-	require LWP::UserAgent;
-	my $ua = LWP::UserAgent->new;
-	$ua->agent("Padre/$VERSION");
-	my $url = $ENV{PADRE_URL} || 'http://peride.org/popularity';
-	my $req = HTTP::Request->new( POST => $url );
-	$req->content_type('application/x-www-form-urlencoded');
+	# Prepare the information to send
+	my %data = (
+		padre  => $VERSION,
+		perl   => $],
+		osname => $^O,
+	);
+	if ( $0 =~ /padre$/ ) {
+		my $dir = $0;
+		$dir =~ s/padre$//;
+		my $revision = Padre::Util::svn_directory_revision($dir);
+		if ( -d "$dir.svn" ) {
+			$data{svn} = $revision;
+		}
+	}
 
-	# TODO the data here has to be controlled by the user
-	my %data;
-	$data{fname} = 'Foo';
-	$data{lname} = 'Bar';
+	# Generate the request URL
+	my $url = URI->new('http://peride.org/popularity');
+	$url->query_form( \%data, ';' );
 
-	#	$data{padre} = $VERSION;
-	#	$data{perl}  = $];
-	#	$data{os}    = $^O;
-
-	require YAML::Tiny;
-	my $content = YAML::Tiny::Dump( \%data );
-	$req->content($content);
-
-	my $res = $ua->request($req);
-
-	return 1;
+	# Hand off to the parent constructor
+	return $class->SUPER::new( request => HTTP::Request->new( GET => $url->as_string ) );
 }
 
 1;
