@@ -7,8 +7,8 @@ use Padre::Task    ();
 use Padre::Current ();
 use Padre::Wx      ();
 
-our $VERSION = '0.35';
-use base 'Padre::Task';
+our $VERSION = '0.36';
+our @ISA     = 'Padre::Task';
 
 =pod
 
