@@ -8,7 +8,7 @@ use warnings;
 use Params::Util qw{_INSTANCE};
 use Padre::Wx ();
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 # Due to an overly simplistic implementation at the C level,
 # Wx::AuiManager is only a SCALAR reference and cannot be
@@ -67,11 +67,8 @@ sub lock_panels {
 	my $unlock = $_[0] ? 0 : 1;
 
 	$self->Update;
-
 	$self->GetPane('bottom')->CaptionVisible($unlock)->Floatable($unlock)->Dockable($unlock)->Movable($unlock);
-
 	$self->GetPane('right')->CaptionVisible($unlock)->Floatable($unlock)->Dockable($unlock)->Movable($unlock);
-
 	$self->Update;
 
 	return;
@@ -97,23 +94,22 @@ sub lock_panels {
 # PPS: Anybody who manages to fix this for real AND explain to me
 #      what the HELL is happening will get a beer on the next
 #      occasion!
-{
+SCOPE: {
 	no warnings 'redefine';
 	no strict;
-	my $destroy = \&Wx::AuiManager::DESTROY;
-	my %destroyed_managers;
+	my $destroy  = \&Wx::AuiManager::DESTROY;
+	my %managers = ();
 	*Wx::AuiManager::DESTROY = sub {
 
-		#		print "$_[0]\n";
-		#		my $i = 0;
-		#		while (1) {
-		#			my @c = caller($i++);
-		#			last if @c < 3;
-		#			print "$i: $c[0] - $c[1] - $c[2] - $c[3]\n";
-		#		}
-
-		if ( not exists $destroyed_managers{"$_[0]"} ) {
-			$destroyed_managers{"$_[0]"}++;
+		#print "$_[0]\n";
+		#my $i = 0;
+		#while (1) {
+		#my @c = caller($i++);
+		#last if @c < 3;
+		#print "$i: $c[0] - $c[1] - $c[2] - $c[3]\n";
+		#}
+		unless ( exists $managers{"$_[0]"} ) {
+			$managers{"$_[0]"}++;
 			goto &$destroy;
 		}
 	};
