@@ -6,8 +6,8 @@ use strict;
 use warnings;
 use Padre::Wx ();
 
-our $VERSION = '0.35';
-use base 'Wx::AuiNotebook';
+our $VERSION = '0.36';
+our @ISA     = 'Wx::AuiNotebook';
 
 sub new {
 	my $class = shift;
