@@ -6,8 +6,8 @@ use warnings;
 use Params::Util qw{_INSTANCE};
 use Padre::Wx ();
 
-our $VERSION = '0.35';
-use base 'Wx::ListView';
+our $VERSION = '0.36';
+our @ISA     = 'Wx::ListView';
 
 sub new {
 	my $class = shift;
