@@ -1,17 +1,28 @@
 package Padre::Wx::Dialog::Find;
 
-# Find and Replace widget
+=pod
+
+=head1 NAME
+
+Padre::Wx::Dialog::Find - Find and Replace widget
+
+=head1 DESCRIPTION
+
+C<Padre::Wx:Main> implements Padre's Find and Replace dialogs.
+Inherits from C<Padre::Wx::Dialog>.
+
+=cut
 
 use 5.008;
 use strict;
 use warnings;
 use Params::Util qw{_STRING};
-use Padre::DB ();
-use Padre::Wx ();
+use Padre::DB         ();
+use Padre::Wx         ();
+use Padre::Wx::Dialog ();
 
-use base qw(Padre::Wx::Dialog);
-
-our $VERSION = '0.35';
+our $VERSION = '0.36';
+our @ISA     = 'Padre::Wx::Dialog';
 
 my @cbs = qw(
 	find_case
@@ -20,15 +31,49 @@ my @cbs = qw(
 	find_first
 );
 
+=pod
+
+=head1 PUBLIC API
+
+=head2 Constructor
+
+=over 4
+
+=item new( $type )
+
+Create and return a C<Padre::Wx::Dialog::Find> object.  Takes dialog
+type (C<find> or C<replace>) as a parameter.  If none given assumes
+the type is C<find>.  Stores dialog type in C<dialog_type>.
+
+    my $find_dialog = Padre::Wx::Dialog::Find->new('find');
+
+=back
+
+=cut
+
 sub new {
 	my $class = shift;
-	my $self = bless {}, $class;
+	my $type  = shift;
+	my $self  = bless {}, $class;
 
+	$self->{dialog_type} = $type ? $type : 'find';
 	$self->create_dialog;
 
 	return $self;
 }
 
+=pod
+
+=head2 Public Methods
+
+=over 4
+
+=item * $self->relocale;
+
+Delete and re-create dialog on locale (language) change.
+
+=cut
+
 sub relocale {
 	my $self = shift;
 
@@ -38,6 +83,14 @@ sub relocale {
 	return;
 }
 
+=pod
+
+=item * $self->delete_dialog;
+
+Delete dialog.
+
+=cut
+
 sub delete_dialog {
 	my $self = shift;
 
@@ -47,15 +100,29 @@ sub delete_dialog {
 	return;
 }
 
-sub create_dialog {
-	my $self = shift;
+=pod
 
+=item * $self->create_dialog;
+
+Create Find or Replace dialog depending on C<dialog_type> value.
+
+TODO: Maybe create methods for Find and Replace dialogs should
+be separated?
+
+=cut
+
+sub create_dialog {
+	my $self   = shift;
 	my $config = Padre->ide->config;
+	my $title
+		= $self->{dialog_type} eq 'replace'
+		? Wx::gettext('Replace')
+		: Wx::gettext('Find');
 
 	$self->{dialog} = Wx::Dialog->new(
 		Padre->ide->wx->main,
 		-1,
-		Wx::gettext('Find'),
+		$title,
 		Wx::wxDefaultPosition,
 		Wx::wxDefaultSize,
 		Wx::wxCAPTION
@@ -64,133 +131,184 @@ sub create_dialog {
 			| Wx::wxSYSTEM_MENU,
 	);
 
-	my $main_sizer = Wx::FlexGridSizer->new( 2, 2, 0, 0 );
+	my $main_sizer = Wx::FlexGridSizer->new( 1, 1, 0, 0 );
 	$main_sizer->AddGrowableCol(0);
 	$self->{dialog}->SetSizer($main_sizer);
 
-	my $left_top_sizer = Wx::FlexGridSizer->new( 2, 2, 0, 0 );
-	$left_top_sizer->AddGrowableCol(1);
-	$main_sizer->Add( $left_top_sizer, 2, Wx::wxALIGN_CENTER_HORIZONTAL | Wx::wxGROW | Wx::wxALL, 5 );
+	# Prepare widgets used in Find/Replace dialogs
+	## widgets used in find_sizer
+	$self->add_widget( '_find_choice_', Wx::ComboBox->new( $self->{dialog} ) );
+	$self->add_widget(
+		'find_regex',
+		Wx::CheckBox->new( $self->{dialog}, -1, Wx::gettext('&Use Regex') )
+	);
+	$self->get_widget('find_regex')->SetValue( $config->find_regex ? 1 : 0 );
+	## widgets used in replace_sizer
+	if ( $self->{dialog_type} eq 'replace' ) {
+		$self->add_widget( '_replace_choice_', Wx::ComboBox->new( $self->{dialog} ) );
+	}
+	## widgets used in options_sizer
+	$self->add_widget(
+		'find_case',
+		Wx::CheckBox->new( $self->{dialog}, -1, Wx::gettext('Case &Insensitive') )
+	);
+	$self->get_widget('find_case')->SetValue( $config->find_case ? 0 : 1 );
+	$self->add_widget(
+		'find_reverse',
+		Wx::CheckBox->new( $self->{dialog}, -1, Wx::gettext('Search &Backwards') )
+	);
+	$self->get_widget('find_reverse')->SetValue( $config->find_reverse ? 1 : 0 );
+	$self->add_widget(
+		'find_first',
+		Wx::CheckBox->new( $self->{dialog}, -1, Wx::gettext('Close Window on &hit') )
+	);
+	$self->get_widget('find_first')->SetValue( $config->find_first ? 1 : 0 );
+	## widgets used in bottom_sizer
+	if ( $self->{dialog_type} eq 'replace' ) {
+		$self->add_widget(
+			'_replace_',
+			Wx::Button->new( $self->{dialog}, Wx::wxID_REPLACE, Wx::gettext("&Replace") )
+		);
+		$self->add_widget(
+			'_replace_all_',
+			Wx::Button->new( $self->{dialog}, Wx::wxID_REPLACE_ALL, Wx::gettext("Replace &all") )
+		);
+	} else {
+		$self->add_widget(
+			'_find_',
+			Wx::Button->new( $self->{dialog}, Wx::wxID_FIND, Wx::gettext("&Find") )
+		);
+	}
+	$self->add_widget(
+		'_cancel_',
+		Wx::Button->new( $self->{dialog}, Wx::wxID_CANCEL, Wx::gettext("&Cancel") )
+	);
 
-	$left_top_sizer->Add(
-		Wx::StaticText->new( $self->{dialog}, Wx::wxID_STATIC, Wx::gettext("Find:") ),
+	# Find sizer begins here
+	my $find_sizer = Wx::StaticBoxSizer->new(
+		Wx::StaticBox->new( $self->{dialog}, -1, Wx::gettext('Find') ),
+		Wx::wxVERTICAL
+	);
+	$main_sizer->Add( $find_sizer, 2, Wx::wxALIGN_CENTER_HORIZONTAL | Wx::wxGROW | Wx::wxALL, 5 );
+
+	$find_sizer->Add(
+		Wx::StaticText->new( $self->{dialog}, Wx::wxID_STATIC, Wx::gettext("Text to find:") ),
 		0,
 		Wx::wxALIGN_LEFT | Wx::wxALIGN_CENTER_VERTICAL | Wx::wxALL,
 		5
 	);
-
-	$self->add_widget( '_find_choice_', Wx::ComboBox->new( $self->{dialog} ) );
-	$left_top_sizer->Add(
+	$find_sizer->Add(
 		$self->get_widget('_find_choice_'),
 		3,
 		Wx::wxGROW | Wx::wxALIGN_CENTER_VERTICAL | Wx::wxALL,
 		5
 	);
-
-	$left_top_sizer->Add(
-		Wx::StaticText->new( $self->{dialog}, Wx::wxID_STATIC, Wx::gettext("Replace with:") ),
-		0,
-		Wx::wxALIGN_LEFT | Wx::wxALIGN_CENTER_VERTICAL | Wx::wxALL,
-		5
-	);
-
-	$self->add_widget( '_replace_choice_', Wx::ComboBox->new( $self->{dialog} ) );
-	$left_top_sizer->Add(
-		$self->get_widget('_replace_choice_'),
-		3,
-		Wx::wxGROW | Wx::wxALIGN_CENTER_VERTICAL | Wx::wxALL,
-		5
-	);
-
-	my $right_top_sizer = Wx::BoxSizer->new(Wx::wxVERTICAL);
-	$main_sizer->Add(
-		$right_top_sizer,
-		0,
-		Wx::wxGROW | Wx::wxALIGN_CENTER_VERTICAL | Wx::wxLEFT | Wx::wxRIGHT,
-		5
-	);
-
-	$self->add_widget( '_find_', Wx::Button->new( $self->{dialog}, Wx::wxID_FIND, Wx::gettext("&Find") ) );
-	$right_top_sizer->Add(
-		$self->get_widget('_find_'),
-		1,
-		Wx::wxGROW | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxTOP,
-		5
-	);
-
-	$self->add_widget( '_replace_', Wx::Button->new( $self->{dialog}, Wx::wxID_REPLACE, Wx::gettext("&Replace") ) );
-	$right_top_sizer->Add(
-		$self->get_widget('_replace_'),
-		1,
-		Wx::wxGROW | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxTOP,
-		5
-	);
-
-	my $left_bottom_sizer = Wx::BoxSizer->new(Wx::wxVERTICAL);
-	$main_sizer->Add(
-		$left_bottom_sizer,
-		2,
-		Wx::wxGROW | Wx::wxALIGN_CENTER_VERTICAL | Wx::wxALL,
-		5
-	);
-
-	$self->add_widget( 'find_case', Wx::CheckBox->new( $self->{dialog}, -1, Wx::gettext('Case &Insensitive') ) );
-	$self->get_widget('find_case')->SetValue( $config->find_case ? 0 : 1 );
-	$left_bottom_sizer->Add(
-		$self->get_widget('find_case'),
-		0,
-		Wx::wxALIGN_LEFT | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxTOP,
-		5
-	);
-
-	$self->add_widget( 'find_regex', Wx::CheckBox->new( $self->{dialog}, -1, Wx::gettext('&Use Regex') ) );
-	$self->get_widget('find_regex')->SetValue( $config->find_regex ? 1 : 0 );
-	$left_bottom_sizer->Add(
+	$find_sizer->Add(
 		$self->get_widget('find_regex'),
 		0,
 		Wx::wxALIGN_LEFT | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxTOP,
 		5
 	);
 
-	$self->add_widget( 'find_reverse', Wx::CheckBox->new( $self->{dialog}, -1, Wx::gettext('Search &Backwards') ) );
-	$self->get_widget('find_reverse')->SetValue( $config->find_reverse ? 1 : 0 );
-	$left_bottom_sizer->Add(
+	# Replace sizer begins here
+	if ( $self->{dialog_type} eq 'replace' ) {
+		my $replace_sizer = Wx::StaticBoxSizer->new(
+			Wx::StaticBox->new( $self->{dialog}, -1, Wx::gettext('Replace With') ),
+			Wx::wxVERTICAL
+		);
+		$main_sizer->Add(
+			$replace_sizer,
+			2,
+			Wx::wxALIGN_CENTER_HORIZONTAL | Wx::wxGROW | Wx::wxALL,
+			5
+		);
+
+		$replace_sizer->Add(
+			Wx::StaticText->new(
+				$self->{dialog},
+				Wx::wxID_STATIC,
+				Wx::gettext("Replacement text:")
+			),
+			0,
+			Wx::wxALIGN_LEFT | Wx::wxALIGN_CENTER_VERTICAL | Wx::wxALL,
+			5
+		);
+		$replace_sizer->Add(
+			$self->get_widget('_replace_choice_'),
+			3,
+			Wx::wxGROW | Wx::wxALIGN_CENTER_VERTICAL | Wx::wxALL,
+			5
+		);
+	}
+
+	# Options sizer begins here
+	my $options_sizer = Wx::StaticBoxSizer->new(
+		Wx::StaticBox->new(
+			$self->{dialog},
+			-1,
+			Wx::gettext('Options')
+		),
+		Wx::wxVERTICAL
+	);
+	$main_sizer->Add( $options_sizer, 2, Wx::wxALIGN_CENTER_HORIZONTAL | Wx::wxGROW | Wx::wxALL, 5 );
+
+	my $options_grid_sizer = Wx::FlexGridSizer->new( 2, 2, 0, 0 );
+	$options_grid_sizer->AddGrowableCol(1);
+	$options_sizer->Add(
+		$options_grid_sizer,
+		2,
+		Wx::wxALIGN_CENTER_HORIZONTAL | Wx::wxGROW | Wx::wxALL,
+		0
+	);
+
+	$options_grid_sizer->Add(
+		$self->get_widget('find_case'),
+		0,
+		Wx::wxALIGN_LEFT | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxTOP,
+		5
+	);
+	$options_grid_sizer->Add(
 		$self->get_widget('find_reverse'),
 		0,
 		Wx::wxALIGN_LEFT | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxTOP,
 		5
 	);
-
-	$self->add_widget( 'find_first', Wx::CheckBox->new( $self->{dialog}, -1, Wx::gettext('Close Window on &hit') ) );
-	$self->get_widget('find_first')->SetValue( $config->find_first ? 1 : 0 );
-	$left_bottom_sizer->Add(
+	$options_grid_sizer->Add(
 		$self->get_widget('find_first'),
 		0,
 		Wx::wxALIGN_LEFT | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxTOP,
 		5
 	);
 
-	my $right_bottom_sizer = Wx::BoxSizer->new(Wx::wxVERTICAL);
-	$main_sizer->Add( $right_bottom_sizer, 0, Wx::wxALIGN_CENTER_HORIZONTAL | Wx::wxGROW | Wx::wxALL, 5 );
+	# Bottom sizer begins here
+	my $bottom_sizer = Wx::BoxSizer->new(Wx::wxHORIZONTAL);
+	$main_sizer->Add( $bottom_sizer, 0, Wx::wxALIGN_RIGHT | Wx::wxALL, 5 );
 
-	$self->add_widget(
-		'_replace_all_',
-		Wx::Button->new( $self->{dialog}, Wx::wxID_REPLACE_ALL, Wx::gettext("Replace &all") )
-	);
-	$right_bottom_sizer->Add(
-		$self->get_widget('_replace_all_'),
-		0,
-		Wx::wxGROW | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxBOTTOM,
-		5
-	);
-
-	$right_bottom_sizer->Add( 5, 5, 5, Wx::wxALIGN_CENTER_HORIZONTAL | Wx::wxALL, 5 );
-
-	$self->add_widget( '_cancel_', Wx::Button->new( $self->{dialog}, Wx::wxID_CANCEL, Wx::gettext("&Cancel") ) );
-	$right_bottom_sizer->Add(
+	if ( $self->{dialog_type} eq 'replace' ) {
+		$bottom_sizer->Add(
+			$self->get_widget('_replace_'),
+			0,
+			Wx::wxGROW | Wx::wxRIGHT,
+			5
+		);
+		$bottom_sizer->Add(
+			$self->get_widget('_replace_all_'),
+			0,
+			Wx::wxGROW | Wx::wxLEFT | Wx::wxRIGHT,
+			5
+		);
+	} else {
+		$bottom_sizer->Add(
+			$self->get_widget('_find_'),
+			0,
+			Wx::wxGROW | Wx::wxRIGHT,
+			5
+		);
+	}
+	$bottom_sizer->Add(
 		$self->get_widget('_cancel_'),
 		0,
-		Wx::wxGROW | Wx::wxLEFT | Wx::wxRIGHT | Wx::wxBOTTOM,
+		Wx::wxGROW | Wx::wxLEFT,
 		5
 	);
 
@@ -206,51 +324,89 @@ sub create_dialog {
 		);
 	}
 
-	$self->get_widget('_find_')->SetDefault;
+	$self->{dialog_type} eq 'replace'
+		? $self->get_widget('_replace_')->SetDefault
+		: $self->get_widget('_find_')->SetDefault;
+
 	Wx::Event::EVT_BUTTON(
 		$self->{dialog},
 		$self->get_widget('_find_'),
-		sub { $self->find_clicked }
+		sub {
+			$self->find_clicked;
+		}
 	);
 	Wx::Event::EVT_BUTTON(
 		$self->{dialog},
 		$self->get_widget('_replace_'),
-		sub { $self->replace_clicked }
+		sub {
+			$self->replace_clicked;
+		}
 	);
 	Wx::Event::EVT_BUTTON(
 		$self->{dialog},
 		$self->get_widget('_replace_all_'),
-		sub { $self->replace_all_clicked }
+		sub {
+			$self->replace_all_clicked;
+		}
 	);
 	Wx::Event::EVT_BUTTON(
 		$self->{dialog},
 		$self->get_widget('_cancel_'),
-		sub { $self->cancel_clicked }
+		sub {
+			$self->cancel_clicked;
+		}
 	);
 
 	return;
 }
 
+=pod
+
+=item * $self->update_dialog;
+
+Fetch recent search and replace strings from history and place them
+in find and replace combo boxes respectively for re-use. 
+
+=cut
+
 sub update_dialog {
 	my $self = shift;
 
-	my $find_combobox = $self->get_widget('_find_choice_');
-	$find_combobox->Clear;
+	my $find = $self->get_widget('_find_choice_');
+	$find->Clear;
 	foreach my $s ( Padre::DB::History->recent('search') ) {
-		$find_combobox->Append($s);
+		$find->Append($s);
 	}
 
-	my $replace_combobox = $self->get_widget('_replace_choice_');
-	$replace_combobox->Clear;
-	foreach my $r ( Padre::DB::History->recent('replace') ) {
-		$replace_combobox->Append($r);
+	if ( $self->{dialog_type} eq 'replace' ) {
+		my $replace = $self->get_widget('_replace_choice_');
+		$replace->Clear;
+		foreach my $r ( Padre::DB::History->recent('replace') ) {
+			$replace->Append($r);
+		}
+		$self->get_widget_value('_find_choice_') ne ''
+			? $replace->SetFocus
+			: $find->SetFocus;
+	} else {
+		$find->SetFocus;
 	}
 
-	$find_combobox->SetFocus;
-
 	return;
 }
 
+=pod
+
+=item * $self->find;
+
+Grab currently selected text, if any, and place it in find combo box.
+Bring up the dialog or perform search for strings' next occurence
+if dialog is already displayed.
+
+TODO: if selection is more than one line then consider it as the limit
+of the search and replace and not as the string to be used.
+
+=cut
+
 sub find {
 	my ( $self, $main ) = @_;
 
@@ -261,8 +417,8 @@ sub find {
 	# of the search and replace and not as the string to be used
 	$text = '' if $text =~ /\n/;
 
-	$self->update_dialog;
 	$self->get_widget('_find_choice_')->SetValue($text);
+	$self->update_dialog;
 
 	if ( $self->{dialog}->IsShown ) {
 		Padre::Wx::Dialog::Find->find_next($main);
@@ -273,6 +429,16 @@ sub find {
 	return;
 }
 
+=pod
+
+=item * $self->find_next;
+
+Search for given string's next occurence.  If no string is available
+(either as a selected text in editor, if Quick Find is on, or from
+search history) run C<find> method.
+
+=cut
+
 sub find_next {
 	my $self = shift;
 	my $main = shift;
@@ -299,6 +465,15 @@ sub find_next {
 	return;
 }
 
+=pod
+
+=item * $self->find_previous;
+
+Perform backward search for string fetched from search history
+or run C<find> method if search history is empty.
+
+=cut
+
 sub find_previous {
 	my $self = shift;
 	my $main = shift;
@@ -311,6 +486,14 @@ sub find_previous {
 	return;
 }
 
+=pod
+
+=item * $self->cancel_clicked;
+
+Hide dialog when pressed cancel button.
+
+=cut
+
 sub cancel_clicked {
 	$_[0]->{dialog}->Hide;
 
@@ -319,6 +502,15 @@ sub cancel_clicked {
 	return;
 }
 
+=pod
+
+=item * $self->replace_all_clicked;
+
+Executed when Replace all button is clicked.
+Replace all appearances of given string.
+
+=cut
+
 sub replace_all_clicked {
 	my ( $self, $dialog, $event ) = @_;
 
@@ -332,7 +524,7 @@ sub replace_all_clicked {
 	my $page    = $current->editor;
 	my $last    = $page->GetLength;
 	my $str     = $page->GetTextRange( 0, $last );
-	my $replace = Padre::DB::History->previous('replace') || '';
+	my $replace = $self->_get_replace;
 	$replace =~ s/\\t/\t/g if $replace;
 
 	my ( $start, $end, @matches ) = Padre::Util::get_matches( $str, $regex, 0, 0 );
@@ -349,6 +541,16 @@ sub replace_all_clicked {
 	return;
 }
 
+=pod
+
+=item * $self->replace_clicked;
+
+Executed when Replace button is clicked.
+Replace one appearance of given strings.  If search window is still
+open, run C<search> on the whole text, again.
+
+=cut
+
 sub replace_clicked {
 	my ( $self, $dialog, $event ) = @_;
 
@@ -363,14 +565,12 @@ sub replace_clicked {
 
 	# If they do, replace it
 	if ( defined $start and $start == 0 and $end == length($text) ) {
-
-		# TODO - This can return undef
-		my $replace = Padre::DB::History->previous('replace');
+		my $replace = $self->_get_replace;
 		$replace =~ s/\\t/\t/g;
 		$current->editor->ReplaceSelection($replace);
 	}
 
-	# If search window is still open, run a search_again on the whole text
+	# If search window is still open, run a search on the whole text again
 	my $config = Padre->ide->config;
 	unless ( $config->find_first ) {
 		$self->search;
@@ -379,6 +579,15 @@ sub replace_clicked {
 	return;
 }
 
+=pod
+
+=item * $self->find_clicked;
+
+Executed when Find button is clicked.
+Perform search on the term specified in the dialog.
+
+=cut
+
 sub find_clicked {
 	my $self   = shift;
 	my $dialog = shift;
@@ -390,6 +599,16 @@ sub find_clicked {
 	return;
 }
 
+=pod
+
+=item * $self->get_data_from_dialog;
+
+Gather search and optionaly replace strings from the dialog and store
+them in search history.  Set search options based on the check boxes
+values.
+
+=cut
+
 sub get_data_from_dialog {
 	my $self   = shift;
 	my $dialog = $self->{dialog};
@@ -399,6 +618,7 @@ sub get_data_from_dialog {
 	$config->set( find_regex   => $data->{find_regex}   ? 1 : 0 );
 	$config->set( find_reverse => $data->{find_reverse} ? 1 : 0 );
 	$config->set( find_first   => $data->{find_first}   ? 1 : 0 );
+	$config->write;
 
 	my $search  = $data->{_find_choice_};
 	my $replace = $data->{_replace_choice_};
@@ -422,6 +642,8 @@ sub get_data_from_dialog {
 	return 1;
 }
 
+# Internal method. $self->_get_regex( $regex )
+# Prepare and return search term defined as a regular expression.
 sub _get_regex {
 	my %args        = @_;
 	my $config      = Padre->ide->config;
@@ -453,6 +675,30 @@ sub _get_regex {
 	return $regex;
 }
 
+# Internal method. $self->_get_replace
+# Returns previous replacement string from history
+# or empty if _replace_choice_ widget is empty.
+# Added to be able to use empty string as a replacement text
+# but without storing in (the empty string) in history.
+sub _get_replace {
+	my $self = shift;
+
+	my $replace
+		= $self->get_widget_value('_replace_choice_') eq ''
+		? ''
+		: Padre::DB::History->previous('replace');
+
+	return $replace;
+}
+
+=pod
+
+=item * $self->search;
+
+Perform actual search.  Highlight (set as selected) found string.
+
+=cut
+
 sub search {
 	my $self  = shift;
 	my %args  = @_;
@@ -480,6 +726,22 @@ sub search {
 
 1;
 
+=pod
+
+=back
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2008-2009 The Padre development team as listed in Padre.pm.
+
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the
+LICENSE file included with this module.
+
+=cut
+
 # Copyright 2008-2009 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
