@@ -1,13 +1,16 @@
-#
-# This file is part of Padre, the Perl ide.
-#
-
 package Padre::Wx::Dialog::PluginManager;
 
+# The Plugin Manager GUI for Padre
+
 use strict;
 use warnings;
+use Carp 'croak';
+use Padre::Wx       ();
+use Padre::Wx::Icon ();
+
+our $VERSION = '0.36';
+our @ISA     = 'Wx::Dialog';
 
-use Carp qw{ croak };
 use Class::XSAccessor accessors => {
 	_action       => '_action',          # action of default button
 	_button       => '_button',          # general-purpose button
@@ -24,19 +27,13 @@ use Class::XSAccessor accessors => {
 	_sortreverse  => '_sortreverse',     # list sorting is reversed
 	_whtml        => '_whtml',           # html space for plugin doc
 };
-use Padre::Wx::Icon;
-use Padre::Wx ();
-
-use base 'Wx::Dialog';
-
-our $VERSION = '0.35';
 
 # -- constructor
 
 sub new {
 	my ( $class, $parent, $manager ) = @_;
 
-	# create object
+	# Create object
 	my $self = $class->SUPER::new(
 		$parent,
 		-1,
@@ -49,14 +46,19 @@ sub new {
 	$self->_sortcolumn(0);
 	$self->_sortreverse(0);
 
-	# store plugin manager
-	croak "Missing or invalid Padre::PluginManager object"
-		unless $manager->isa('Padre::PluginManager');
+	# Store plugin manager
+	unless ( $manager->isa('Padre::PluginManager') ) {
+		croak("Missing or invalid Padre::PluginManager object");
+	}
 	$self->_manager($manager);
 
-	# create dialog
+	# Create dialog
 	$self->_create;
 
+	# Tune the size and position it appears
+	$self->Fit;
+	$self->CentreOnParent;
+
 	return $self;
 }
 
@@ -86,8 +88,7 @@ sub show {
 # handler called when the close button has been clicked.
 #
 sub _on_butclose_clicked {
-	my $self = shift;
-	$self->Destroy;
+	$_[0]->Destroy;
 }
 
 #
@@ -96,8 +97,7 @@ sub _on_butclose_clicked {
 # handler called when the preferences button has been clicked.
 #
 sub _on_butprefs_clicked {
-	my $self = shift;
-	$self->_curplugin->object->plugin_preferences;
+	$_[0]->_curplugin->object->plugin_preferences;
 }
 
 #
@@ -122,8 +122,7 @@ sub _on_button_clicked {
 #
 sub _on_list_col_click {
 	my ( $self, $event ) = @_;
-	my $col = $event->GetColumn;
-
+	my $col      = $event->GetColumn;
 	my $prevcol  = $self->_sortcolumn;
 	my $reversed = $self->_sortreverse;
 	$reversed = $col == $prevcol ? !$reversed : 0;
@@ -162,17 +161,18 @@ sub _on_list_item_selected {
 	$self->_currow( $event->GetIndex );    # storing selected row
 
 	# updating plugin name in right pane
-	$self->_label->SetLabel($name);
+	$self->_label->SetLabel( $plugin->plugin_name );
 
 	# update plugin documentation
-	my $class   = $plugin->class;
+	require Padre::DocBrowser;
 	my $browser = Padre::DocBrowser->new;
+	my $class   = $plugin->class;
 	my $doc     = $browser->resolve($class);
 	my $output  = eval { $browser->browse($doc) };
 	my $html
 		= $@
 		? sprintf( Wx::gettext("Error loading pod for class '%s': %s"), $class, $@ )
-		: $output->{original_content};
+		: $output->body;
 	$self->_whtml->SetPage($html);
 
 	# update buttons
@@ -202,9 +202,10 @@ sub _create {
 	$self->SetSizer($hbox);
 	$self->SetMinSize( [ 800, 600 ] );
 	$self->_hbox($hbox);
-
 	$self->_create_list;
 	$self->_create_right_pane;
+
+	return 1;
 }
 
 #
@@ -262,9 +263,9 @@ sub _create_right_pane {
 
 	# the plugin name
 	my $hbox1 = Wx::BoxSizer->new(Wx::wxHORIZONTAL);
-	$vbox->Add( $hbox1, 0, Wx::wxALL | Wx::wxEXPAND, 1 );
 	my $label = Wx::StaticText->new( $self, -1, 'plugin name' );
-	my $font = $label->GetFont;
+	my $font  = $label->GetFont;
+	$vbox->Add( $hbox1, 0, Wx::wxALL | Wx::wxEXPAND, 1 );
 	$font->SetWeight(Wx::wxFONTWEIGHT_BOLD);
 	$font->SetPointSize( $font->GetPointSize + 2 );
 	$label->SetFont($font);
@@ -274,6 +275,7 @@ sub _create_right_pane {
 	$self->_label($label);
 
 	# the plugin documentation
+	require Padre::Wx::HtmlWindow;
 	my $whtml = Wx::HtmlWindow->new($self);
 	$vbox->Add(
 		$whtml,
@@ -482,7 +484,6 @@ sub _update_plugin_state {
 	} else {
 
 		# plugin is working...
-
 		if ( $plugin->enabled ) {
 
 			# ... and enabled
@@ -528,13 +529,12 @@ sub _update_plugin_state {
 
 __END__
 
+=pod
 
 =head1 NAME
 
 Padre::Wx::Dialog::PluginManager - Plugin manager dialog for Padre
 
-
-
 =head1 DESCRIPTION
 
 Padre will have a lot of plugins. First plugin manager was not taking
@@ -548,11 +548,8 @@ Upon selection, the right pane will be updated with the plugin name &
 plugin documentation. Two buttons will allow to de/activate the plugin
 (or see plugin error message) and set plugin preferences.
 
-
 Double-clicking on a plugin in the list will de/activate it.
 
-
-
 =head1 PUBLIC API
 
 =head2 Constructor
@@ -565,11 +562,8 @@ Create and return a new Wx dialog listing all the plugins. It needs a
 C<$parent> window and a C<Padre::PluginManager> object that really
 handles Padre plugins under the hood.
 
-
 =back
 
-
-
 =head2 Public methods
 
 =over 4
@@ -579,11 +573,8 @@ handles Padre plugins under the hood.
 Request the plugin manager dialog to be shown. It will be refreshed
 first with a current list of plugins with their state.
 
-
 =back
 
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2009 The Padre development team as listed in Padre.pm.
@@ -591,10 +582,8 @@ Copyright 2008-2009 The Padre development team as listed in Padre.pm.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5 itself.
 
-
 =cut
 
-
 # Copyright 2008-2009 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
