@@ -7,8 +7,8 @@ use Params::Util qw{ _STRING };
 use Padre::Wx      ();
 use Padre::Current ();
 
-our $VERSION = '0.35';
-use base 'Wx::ListCtrl';
+our $VERSION = '0.36';
+our @ISA     = 'Wx::ListCtrl';
 
 #####################################################################
 # Constructor
